==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkLabelHierarchy.java <==
// java wrapper for vtkLabelHierarchy object
//

package vtk;
import vtk.*;

public class vtkLabelHierarchy extends vtkPointSet
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPoints_2(vtkPoints id0);
  public void SetPoints(vtkPoints id0)
    { SetPoints_2(id0); }

  private native void ComputeHierarchy_3();
  public void ComputeHierarchy()
    { ComputeHierarchy_3(); }

  private native void SetTargetLabelCount_4(int id0);
  public void SetTargetLabelCount(int id0)
    { SetTargetLabelCount_4(id0); }

  private native int GetTargetLabelCount_5();
  public int GetTargetLabelCount()
    { return GetTargetLabelCount_5(); }

  private native void SetMaximumDepth_6(int id0);
  public void SetMaximumDepth(int id0)
    { SetMaximumDepth_6(id0); }

  private native int GetMaximumDepth_7();
  public int GetMaximumDepth()
    { return GetMaximumDepth_7(); }

  private native void SetTextProperty_8(vtkTextProperty id0);
  public void SetTextProperty(vtkTextProperty id0)
    { SetTextProperty_8(id0); }

  private native long GetTextProperty_9();
  public vtkTextProperty GetTextProperty() {
    long temp = GetTextProperty_9();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetPriorities_10(vtkDataArray id0);
  public void SetPriorities(vtkDataArray id0)
    { SetPriorities_10(id0); }

  private native long GetPriorities_11();
  public vtkDataArray GetPriorities() {
    long temp = GetPriorities_11();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetLabels_12(vtkAbstractArray id0);
  public void SetLabels(vtkAbstractArray id0)
    { SetLabels_12(id0); }

  private native long GetLabels_13();
  public vtkAbstractArray GetLabels() {
    long temp = GetLabels_13();

    if (temp == 0) return null;
    return (vtkAbstractArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetOrientations_14(vtkDataArray id0);
  public void SetOrientations(vtkDataArray id0)
    { SetOrientations_14(id0); }

  private native long GetOrientations_15();
  public vtkDataArray GetOrientations() {
    long temp = GetOrientations_15();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetIconIndices_16(vtkIntArray id0);
  public void SetIconIndices(vtkIntArray id0)
    { SetIconIndices_16(id0); }

  private native long GetIconIndices_17();
  public vtkIntArray GetIconIndices() {
    long temp = GetIconIndices_17();

    if (temp == 0) return null;
    return (vtkIntArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetSizes_18(vtkDataArray id0);
  public void SetSizes(vtkDataArray id0)
    { SetSizes_18(id0); }

  private native long GetSizes_19();
  public vtkDataArray GetSizes() {
    long temp = GetSizes_19();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetBoundedSizes_20(vtkDataArray id0);
  public void SetBoundedSizes(vtkDataArray id0)
    { SetBoundedSizes_20(id0); }

  private native long GetBoundedSizes_21();
  public vtkDataArray GetBoundedSizes() {
    long temp = GetBoundedSizes_21();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long NewIterator_22(int id0,vtkRenderer id1,vtkCamera id2,double id3[],boolean id4,double id5[]);
  public vtkLabelHierarchyIterator NewIterator(int id0,vtkRenderer id1,vtkCamera id2,double id3[],boolean id4,double id5[]) {
    long temp = NewIterator_22(id0,id1,id2,id3,id4,id5);

    if (temp == 0) return null;
    return (vtkLabelHierarchyIterator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void GetDiscreteNodeCoordinatesFromWorldPoint_23(int id0[],double id1[],int id2);
  public void GetDiscreteNodeCoordinatesFromWorldPoint(int id0[],double id1[],int id2)
    { GetDiscreteNodeCoordinatesFromWorldPoint_23(id0,id1,id2); }

  private native int GetNumberOfCells_24();
  public int GetNumberOfCells()
    { return GetNumberOfCells_24(); }

  private native long GetCell_25(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_25(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void GetCell_26(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_26(id0,id1); }

  private native int GetCellType_27(int id0);
  public int GetCellType(int id0)
    { return GetCellType_27(id0); }

  private native void GetCellPoints_28(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_28(id0,id1); }

  private native void GetPointCells_29(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_29(id0,id1); }

  private native int GetMaxCellSize_30();
  public int GetMaxCellSize()
    { return GetMaxCellSize_30(); }

  private native long GetCenterPts_31();
  public vtkPoints GetCenterPts() {
    long temp = GetCenterPts_31();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkLabelHierarchy() { super(); }

  public vtkLabelHierarchy(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkLabelHierarchy.java <==
// java wrapper for vtkLabelHierarchy object
//

package vtk;
import vtk.*;

public class vtkLabelHierarchy extends vtkPointSet
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetPoints_2(vtkPoints id0);
  public void SetPoints(vtkPoints id0)
    { SetPoints_2(id0); }

  private native void ComputeHierarchy_3();
  public void ComputeHierarchy()
    { ComputeHierarchy_3(); }

  private native void SetTargetLabelCount_4(int id0);
  public void SetTargetLabelCount(int id0)
    { SetTargetLabelCount_4(id0); }

  private native int GetTargetLabelCount_5();
  public int GetTargetLabelCount()
    { return GetTargetLabelCount_5(); }

  private native void SetMaximumDepth_6(int id0);
  public void SetMaximumDepth(int id0)
    { SetMaximumDepth_6(id0); }

  private native int GetMaximumDepth_7();
  public int GetMaximumDepth()
    { return GetMaximumDepth_7(); }

  private native void SetTextProperty_8(vtkTextProperty id0);
  public void SetTextProperty(vtkTextProperty id0)
    { SetTextProperty_8(id0); }

  private native long GetTextProperty_9();
  public vtkTextProperty GetTextProperty() {
    long temp = GetTextProperty_9();

    if (temp == 0) return null;
    return (vtkTextProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetPriorities_10(vtkDataArray id0);
  public void SetPriorities(vtkDataArray id0)
    { SetPriorities_10(id0); }

  private native long GetPriorities_11();
  public vtkDataArray GetPriorities() {
    long temp = GetPriorities_11();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetLabels_12(vtkAbstractArray id0);
  public void SetLabels(vtkAbstractArray id0)
    { SetLabels_12(id0); }

  private native long GetLabels_13();
  public vtkAbstractArray GetLabels() {
    long temp = GetLabels_13();

    if (temp == 0) return null;
    return (vtkAbstractArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetOrientations_14(vtkDataArray id0);
  public void SetOrientations(vtkDataArray id0)
    { SetOrientations_14(id0); }

  private native long GetOrientations_15();
  public vtkDataArray GetOrientations() {
    long temp = GetOrientations_15();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetIconIndices_16(vtkIntArray id0);
  public void SetIconIndices(vtkIntArray id0)
    { SetIconIndices_16(id0); }

  private native long GetIconIndices_17();
  public vtkIntArray GetIconIndices() {
    long temp = GetIconIndices_17();

    if (temp == 0) return null;
    return (vtkIntArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSizes_18(vtkDataArray id0);
  public void SetSizes(vtkDataArray id0)
    { SetSizes_18(id0); }

  private native long GetSizes_19();
  public vtkDataArray GetSizes() {
    long temp = GetSizes_19();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBoundedSizes_20(vtkDataArray id0);
  public void SetBoundedSizes(vtkDataArray id0)
    { SetBoundedSizes_20(id0); }

  private native long GetBoundedSizes_21();
  public vtkDataArray GetBoundedSizes() {
    long temp = GetBoundedSizes_21();

    if (temp == 0) return null;
    return (vtkDataArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long NewIterator_22(int id0,vtkRenderer id1,vtkCamera id2,double id3[],boolean id4,double id5[]);
  public vtkLabelHierarchyIterator NewIterator(int id0,vtkRenderer id1,vtkCamera id2,double id3[],boolean id4,double id5[]) {
    long temp = NewIterator_22(id0,id1,id2,id3,id4,id5);

    if (temp == 0) return null;
    return (vtkLabelHierarchyIterator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetDiscreteNodeCoordinatesFromWorldPoint_23(int id0[],double id1[],int id2);
  public void GetDiscreteNodeCoordinatesFromWorldPoint(int id0[],double id1[],int id2)
    { GetDiscreteNodeCoordinatesFromWorldPoint_23(id0,id1,id2); }

  private native int GetNumberOfCells_24();
  public int GetNumberOfCells()
    { return GetNumberOfCells_24(); }

  private native long GetCell_25(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_25(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetCell_26(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_26(id0,id1); }

  private native int GetCellType_27(int id0);
  public int GetCellType(int id0)
    { return GetCellType_27(id0); }

  private native void GetCellPoints_28(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_28(id0,id1); }

  private native void GetPointCells_29(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_29(id0,id1); }

  private native int GetMaxCellSize_30();
  public int GetMaxCellSize()
    { return GetMaxCellSize_30(); }

  private native long GetCenterPts_31();
  public vtkPoints GetCenterPts() {
    long temp = GetCenterPts_31();

    if (temp == 0) return null;
    return (vtkPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCoincidentPoints_32();
  public vtkCoincidentPoints GetCoincidentPoints() {
    long temp = GetCoincidentPoints_32();

    if (temp == 0) return null;
    return (vtkCoincidentPoints)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCell_33(int id0,int id1,int id2);
  public vtkCell GetCell(int id0,int id1,int id2) {
    long temp = GetCell_33(id0,id1,id2);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkLabelHierarchy() { super(); }

  public vtkLabelHierarchy(long id) { super(id); }
  public native long   VTKInit();

}
